@@ -133,9 +133,7 @@ class HiveCliHook(BaseHook):
 
         if self.use_beeline:
             hive_bin = 'beeline'
-            jdbc_url = "jdbc:hive2://{host}:{port}/{schema}".format(
-                host=conn.host, port=conn.port, schema=conn.schema
-            )
+            jdbc_url = f"jdbc:hive2://{conn.host}:{conn.port}/{conn.schema}"
             if conf.get('core', 'security') == 'kerberos':
                 template = conn.extra_dejson.get('principal', "hive/_HOST@EXAMPLE.COM")
                 if "_HOST" in template:
@@ -143,9 +141,7 @@ class HiveCliHook(BaseHook):
 
                 proxy_user = self._get_proxy_user()
 
-                jdbc_url += ";principal={template};{proxy_user}".format(
-                    template=template, proxy_user=proxy_user
-                )
+                jdbc_url += f";principal={template};{proxy_user}"
             elif self.auth:
                 jdbc_url += ";auth=" + self.auth
 
@@ -486,7 +482,7 @@ class HiveMetastoreHook(BaseHook):
         self.metastore = self.get_metastore_client()
 
     def __getstate__(self) -> Dict[str, Any]:
-        # This is for pickling to work despite the thirft hive client not
+        # This is for pickling to work despite the thrift hive client not
         # being pickable
         state = dict(self.__dict__)
         del state['metastore']
@@ -826,6 +822,7 @@ class HiveServer2Hook(DbApiHook):
     def get_conn(self, schema: Optional[str] = None) -> Any:
         """Returns a Hive connection object."""
         username: Optional[str] = None
+        password: Optional[str] = None
         # pylint: disable=no-member
         db = self.get_connection(self.hiveserver2_conn_id)  # type: ignore
 
@@ -846,6 +843,10 @@ class HiveServer2Hook(DbApiHook):
             )
             auth_mechanism = 'KERBEROS'
 
+        # Password should be set if and only if in LDAP or CUSTOM mode
+        if auth_mechanism in ('LDAP', 'CUSTOM'):
+            password = db.password
+
         from pyhive.hive import connect
 
         return connect(
@@ -854,7 +855,7 @@ class HiveServer2Hook(DbApiHook):
             auth=auth_mechanism,
             kerberos_service_name=kerberos_service_name,
             username=db.login or username,
-            password=db.password,
+            password=password,
             database=schema or db.schema or 'default',
         )
 
